@@ -191,7 +191,8 @@ C<authortest> action depends on it.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Geo-WebService-Elevation-USGS/issues>,
+or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -199,7 +200,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2020 Thomas R. Wyant, III
+Copyright (C) 2009-2021 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
